@@ -11,8 +11,8 @@ module ActionCable
   module VERSION
     MAJOR = 8
     MINOR = 0
-    TINY  = 2
-    PRE   = "1"
+    TINY  = 4
+    PRE   = nil
 
     STRING = [MAJOR, MINOR, TINY, PRE].compact.join(".")
   end
